/**
 *******************************************************************************
 * @file    main.c
 * @brief   The application functions of RMC_Receiving demo for the TOSHIBA
 *          'TMPM3Vx' Device Series 
 * @version V0.200
 * @date    2019/05/10
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"

/**
  * @brief  main function
  * @param  None
  * @retval None
  */
int main(void)
{
    CG_SetFs(ENABLE);

    SIO_Configuration(UART0);
    SIO_ChInit();

    Timer_ChInit(TSB_TB0);

    RMC_Configuration(TSB_RMC);   /* RMC IO initial */
    RMC_ChInit(TSB_RMC);          /* Configure RMC */

    /* Initialize Variables */
    gSIORdIndex = 0U;
    gSIOWrIndex = 0U;
    fSIO_INT = 0U;
    fTMRB0_INT = 0U;

    fRMCDone = RMC_NON;
    fRMCPress = RELEASE;

    NVIC_EnableIRQ(INTTX0_IRQn);
    NVIC_EnableIRQ(INTRMCRX_IRQn);

#ifdef TMPM3V6
     printf("TMPM3V6 RMC Receiving DEMO\n");
#elif TMPM3V4
     printf("TMPM3V4 RMC Receiving DEMO\n");
#endif
    while(1) {
        if (fRMCDone == RMC_DONE) {             /* RMC reception complete */
            RMC_SetRxCtrl(TSB_RMC, DISABLE);    /* Stop RMC receiving */
            RMCRcv();                           /* Get TSB_RMC gAddress and gCommand */

            PrintCode(FORMAT, gRMC_Address, gRMC_Command);      /* Print code received by RMC */
            RMC_SetRxCtrl(TSB_RMC, ENABLE);                    /* Start RMC receiving */
        } else {
            /* Do nothing */
        }
    }
}

/**
  * @brief  Print code received by RMC.
  * @param  Format name, address, command
  * @retval None
  */
void PrintCode(char *ch, uint16_t addr, uint32_t cmd)
{
#ifdef RMC_1
    printf("%s: %02x %02x\r\n", ch, addr, cmd);
#endif

#ifdef RMC_2
    printf("%s: %02x %02x\r\n", ch, addr, cmd);
#endif

#ifdef RMC_3
    printf("%s: %04x %06x\r\n", ch, addr, cmd);
#endif

#ifdef RMC_4
    if (gRMC_4Address != 13U) {
        printf("%s: %02x %02x\r\n", ch, addr, cmd);
    } else {
        printf("%s: %04x %02x\r\n", ch, addr, cmd);
    }
#endif

#ifdef RMC_5
    printf("%s: %02x %02x\r\n", ch, addr, cmd);
#endif
#ifdef RMC_6
    printf("%s: %02x %02x\r\n", ch, addr, cmd);
#endif
}

/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
