/**
 ******************************************************************************
 * @file     sw.c
 * @brief    SW driver for the TOSHIBA 'TMPM3Vx' Device Series
 * @version  V0.200
 * @date     2019/05/10
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 ******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "sw.h"

/**
  * @brief  Initialize the GPIO to SW.
  *   SW0/4 connect with PG0/PH4.
  *   SW1/5 connect with PG1/PH5.
  *   SW2/6 connect with PG2/PH6.
  *   SW3/7 connect with PG3/PH7.
  * @param  None
  * @retval None
  */
void SW_Init(void)
{
#ifdef TMPM3V6
    GPIO_SetPullDown(GPIO_PG, GPIO_BIT_0 | GPIO_BIT_1 | GPIO_BIT_2 | GPIO_BIT_3, ENABLE);
    GPIO_SetInput(GPIO_PG,  GPIO_BIT_0 | GPIO_BIT_1 | GPIO_BIT_2 | GPIO_BIT_3);
#elif TMPM3V4
    GPIO_SetPullDown(GPIO_PH, GPIO_BIT_4 | GPIO_BIT_5 | GPIO_BIT_6 | GPIO_BIT_7, ENABLE);
    GPIO_SetInput(GPIO_PH,  GPIO_BIT_4 | GPIO_BIT_5 | GPIO_BIT_6 | GPIO_BIT_7);
#endif
}

/**
  * @brief  Get SW Value.
  * @param  sw: SW number
  *   This parameter can be from SW0 ~ SW7.
  * @retval SW value.
  */
uint8_t SW_Get(uint8_t sw)
{
#ifdef TMPM3V6
    uint8_t tmp = 0U;
    switch (sw) {
    case SW0:
    case SW4:
        if (GPIO_ReadDataBit(GPIO_PG, GPIO_BIT_0) == 0U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    case SW1:
    case SW5:
        if (GPIO_ReadDataBit(GPIO_PG, GPIO_BIT_1) == 0U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    case SW2:
    case SW6:
        if (GPIO_ReadDataBit(GPIO_PG, GPIO_BIT_2) == 0U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    case SW3:
    case SW7:
        if (GPIO_ReadDataBit(GPIO_PG, GPIO_BIT_3) == 0U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    default:
        break;
    }
    
    return tmp;
#elif TMPM3V4
    uint8_t tmp = 0U;
    switch (sw) {
    case SW0:
    case SW4:
        if (GPIO_ReadDataBit(GPIO_PH, GPIO_BIT_4) == 0U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    case SW1:
    case SW5:
        if (GPIO_ReadDataBit(GPIO_PH, GPIO_BIT_5) == 0U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    case SW2:
    case SW6:
        if (GPIO_ReadDataBit(GPIO_PH, GPIO_BIT_6) == 0U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    case SW3:
    case SW7:
        if (GPIO_ReadDataBit(GPIO_PH, GPIO_BIT_7) == 0U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    default:
        break;
    }
    
    return tmp;
#endif
}
